1.17.7 — Rucio 1.2 documentation

# 1.17.7

## General

### Enhancements

- Documentation: Mention upload with PFN should also be with no_register #1464
- Infrastructure: set rucio.cfg values for docker containers with env variables #1432
- Infrastructure: dev docker YAML file #1457

### Bugs

- Core & Internals: No exceptions handled for list_rse_attributes #1155
- Core & Internals: postgres requires ::text conversion of uuid for md5 #1446
- Deletion: Reaper needs to remove archive_contents when removing an archive logically #1433
- Transfers: find_matching_scheme function is not working properly #1434

## Clients

### Enhancements

- Clients: Add a –allow-tape option in rucio download #1404

### Bugs

- Clients: rucio upload –no-register –pfn fails #1377